@@ -8,7 +8,7 @@
 #define __SB_HEADERS_H__
 
 #ifdef HAVE_CONFIG_H
-# include "config.h"
+# include <sandboxconfig.h>
 #endif
 
 #ifdef HAVE_DIRENT_H
@@ -167,6 +167,4 @@
 # include "localdecls.h"
 #endif
 
-#include "libsbutil/gnulib/glue.h"
-
 #endif
